@@ -95,7 +95,7 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     @Override
     public void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
-        mAdapter = new VideoListAdapter(this, mGroup != null);
+        mAdapter = new VideoListAdapter(this);
 
         if (savedInstanceState != null)
             setGroup(savedInstanceState.getString(KEY_GROUP));
@@ -294,18 +294,20 @@ public class VideoGridFragment extends SortableFragment<VideoListAdapter> implem
     private void removeVideo(final MediaWrapper media) {
         final int position = mAdapter.remove(media);
         final View view = getView();
-        if (position != -1 && view != null)
-            UiTools.snackerWithCancel(view, getString(R.string.file_deleted), new Runnable() {
-                @Override
-                public void run() {
-                    deleteMedia(media, false);
-                }
-            }, new Runnable() {
+        if (position != -1 && view != null) {
+            final Runnable revert = new Runnable() {
                 @Override
                 public void run() {
                     mAdapter.add(media, position);
                 }
-            });
+            };
+            UiTools.snackerWithCancel(view, getString(R.string.file_deleted), new Runnable() {
+                @Override
+                public void run() {
+                    deleteMedia(media, false, revert);
+                }
+            }, revert);
+        }
     }
 
     @Override
